@@ -1,7 +1,7 @@
 /* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
+ * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation;
  *
  * This program is distributed in the hope that it will be useful,
@@ -16,34 +16,38 @@
  * Author: Marco Guastella <vasta@ragnu.it>
  */
 
+#include "config.h" 
 #include <stdio.h>
-#include <stdlib.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 void usage()
 {
-	fprintf(stderr,"lupin {-v |-l|-n}\n");
+	fprintf(stdout,"Author:Guastella Marco alias vasta\nhome page:http://www.ragnu.it\ncontact:vasta@ragnu.it\nversion:%s\nlicence:GPL3\n",VERSION);
+	fprintf(stderr,"usage:lupin {-v |-l|-n}\n");
 	exit(EXIT_FAILURE);	
 }
+
 int main(int argc,char *argv[])
 {
 	int c;	
-	if(argc	!= 2)
+	if(argc != 2)
 		usage();
 	if((c=getopt(argc,argv,"vln"))!=-1)
 	{
 		switch(c)
 		{		
-			case 'v':printf("0.1.2\n");
-		       		break;
-			case 'l':printf("-llupin ");
-                	       break;
-			case 'n':printf("2");
+			case 'v':fprintf(stdout,"0.2.3\n");
+		       		     break;
+			case 'l':fprintf(stdout,"-llupin ");
+				     break;
+			case 'n':fprintf(stdout,"3");
 				      break;
-			default:usage();
-				break;
+			default: usage();
+					break;
 		}	
 	}		
 	exit(EXIT_SUCCESS);
+	return 0;
 }
 
